@@ -24,8 +24,8 @@ from django.utils.html import escape
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext as _
 
-from sentry.constants import STATUS_MUTED, EVENTS_PER_PAGE
-from sentry.models import Group, Option
+from sentry.constants import STATUS_MUTED, EVENTS_PER_PAGE, MEMBER_OWNER
+from sentry.models import Team, Group, Option
 from sentry.web.helpers import group_is_public
 from sentry.utils import to_unicode
 from sentry.utils.avatar import get_gravatar_url
@@ -285,10 +285,10 @@ def get_project_dsn(context, user, project, asvar):
         return ''
 
     try:
-        key = ProjectKey.objects.get(user=user, project=project)
+        key = ProjectKey.objects.filter(user=None, project=project)[0]
     except ProjectKey.DoesNotExist:
         try:
-            key = ProjectKey.objects.filter(user=None, project=project)[0]
+            key = ProjectKey.objects.get(user=user, project=project)
         except IndexError:
             context[asvar] = None
         else:
@@ -465,3 +465,14 @@ def urlquote(value, safe=''):
 @register.filter
 def basename(value):
     return os.path.basename(value)
+
+
+@register.filter
+def can_admin_team(user, team):
+    if user.is_superuser:
+        return True
+    if team.owner == user:
+        return True
+    if team in Team.objects.get_for_user(user, access=MEMBER_OWNER):
+        return True
+    return False
